=======
History
=======

0.1.7 (2023-09-11)
------------------

* Update Pincode data to latest (Sept 2023)
* Added coordinates info with pins
* Fetch longitude and latitude of any pin
* Update security vulnerabilities

0.1.0 (2021-07-27)
------------------

* Match location with the pins
* Mark pin is valid or not
* Extract cities on basis of pins
